@@ -16,7 +16,17 @@
 from collections import OrderedDict
 import functools
 import re
-from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
+from typing import (
+    Dict,
+    Mapping,
+    MutableMapping,
+    MutableSequence,
+    Optional,
+    Sequence,
+    Tuple,
+    Type,
+    Union,
+)
 
 from google.api_core import exceptions as core_exceptions
 from google.api_core import gapic_v1
@@ -175,9 +185,9 @@ class DocumentServiceAsyncClient:
     def __init__(
         self,
         *,
-        credentials: ga_credentials.Credentials = None,
+        credentials: Optional[ga_credentials.Credentials] = None,
         transport: Union[str, DocumentServiceTransport] = "grpc_asyncio",
-        client_options: ClientOptions = None,
+        client_options: Optional[ClientOptions] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
     ) -> None:
         """Instantiates the document service client.
@@ -221,12 +231,14 @@ class DocumentServiceAsyncClient:
 
     async def create_document(
         self,
-        request: Union[document_service_request.CreateDocumentRequest, dict] = None,
+        request: Optional[
+            Union[document_service_request.CreateDocumentRequest, dict]
+        ] = None,
         *,
-        parent: str = None,
-        document: gcc_document.Document = None,
+        parent: Optional[str] = None,
+        document: Optional[gcc_document.Document] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Optional[float] = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> document_service.CreateDocumentResponse:
         r"""Creates a document.
@@ -264,7 +276,7 @@ class DocumentServiceAsyncClient:
                 print(response)
 
         Args:
-            request (Union[google.cloud.contentwarehouse_v1.types.CreateDocumentRequest, dict]):
+            request (Optional[Union[google.cloud.contentwarehouse_v1.types.CreateDocumentRequest, dict]]):
                 The request object. Request message for
                 DocumentService.CreateDocument.
             parent (:class:`str`):
@@ -337,11 +349,13 @@ class DocumentServiceAsyncClient:
 
     async def get_document(
         self,
-        request: Union[document_service_request.GetDocumentRequest, dict] = None,
+        request: Optional[
+            Union[document_service_request.GetDocumentRequest, dict]
+        ] = None,
         *,
-        name: str = None,
+        name: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Optional[float] = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> gcc_document.Document:
         r"""Gets a document. Returns NOT_FOUND if the document does not
@@ -374,7 +388,7 @@ class DocumentServiceAsyncClient:
                 print(response)
 
         Args:
-            request (Union[google.cloud.contentwarehouse_v1.types.GetDocumentRequest, dict]):
+            request (Optional[Union[google.cloud.contentwarehouse_v1.types.GetDocumentRequest, dict]]):
                 The request object. Request message for
                 DocumentService.GetDocument.
             name (:class:`str`):
@@ -451,12 +465,14 @@ class DocumentServiceAsyncClient:
 
     async def update_document(
         self,
-        request: Union[document_service_request.UpdateDocumentRequest, dict] = None,
+        request: Optional[
+            Union[document_service_request.UpdateDocumentRequest, dict]
+        ] = None,
         *,
-        name: str = None,
-        document: gcc_document.Document = None,
+        name: Optional[str] = None,
+        document: Optional[gcc_document.Document] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Optional[float] = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> document_service.UpdateDocumentResponse:
         r"""Updates a document. Returns INVALID_ARGUMENT if the name of the
@@ -495,7 +511,7 @@ class DocumentServiceAsyncClient:
                 print(response)
 
         Args:
-            request (Union[google.cloud.contentwarehouse_v1.types.UpdateDocumentRequest, dict]):
+            request (Optional[Union[google.cloud.contentwarehouse_v1.types.UpdateDocumentRequest, dict]]):
                 The request object. Request message for
                 DocumentService.UpdateDocument.
             name (:class:`str`):
@@ -570,11 +586,13 @@ class DocumentServiceAsyncClient:
 
     async def delete_document(
         self,
-        request: Union[document_service_request.DeleteDocumentRequest, dict] = None,
+        request: Optional[
+            Union[document_service_request.DeleteDocumentRequest, dict]
+        ] = None,
         *,
-        name: str = None,
+        name: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Optional[float] = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> None:
         r"""Deletes a document. Returns NOT_FOUND if the document does not
@@ -604,7 +622,7 @@ class DocumentServiceAsyncClient:
                 await client.delete_document(request=request)
 
         Args:
-            request (Union[google.cloud.contentwarehouse_v1.types.DeleteDocumentRequest, dict]):
+            request (Optional[Union[google.cloud.contentwarehouse_v1.types.DeleteDocumentRequest, dict]]):
                 The request object. Request message for
                 DocumentService.DeleteDocument.
             name (:class:`str`):
@@ -663,11 +681,13 @@ class DocumentServiceAsyncClient:
 
     async def search_documents(
         self,
-        request: Union[document_service_request.SearchDocumentsRequest, dict] = None,
+        request: Optional[
+            Union[document_service_request.SearchDocumentsRequest, dict]
+        ] = None,
         *,
-        parent: str = None,
+        parent: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Optional[float] = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.SearchDocumentsAsyncPager:
         r"""Searches for documents using provided
@@ -703,7 +723,7 @@ class DocumentServiceAsyncClient:
                     print(response)
 
         Args:
-            request (Union[google.cloud.contentwarehouse_v1.types.SearchDocumentsRequest, dict]):
+            request (Optional[Union[google.cloud.contentwarehouse_v1.types.SearchDocumentsRequest, dict]]):
                 The request object. Request message for
                 DocumentService.SearchDocuments.
             parent (:class:`str`):
@@ -782,11 +802,11 @@ class DocumentServiceAsyncClient:
 
     async def fetch_acl(
         self,
-        request: Union[document_service_request.FetchAclRequest, dict] = None,
+        request: Optional[Union[document_service_request.FetchAclRequest, dict]] = None,
         *,
-        resource: str = None,
+        resource: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Optional[float] = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> document_service.FetchAclResponse:
         r"""Gets the access control policy for a resource. Returns NOT_FOUND
@@ -820,7 +840,7 @@ class DocumentServiceAsyncClient:
                 print(response)
 
         Args:
-            request (Union[google.cloud.contentwarehouse_v1.types.FetchAclRequest, dict]):
+            request (Optional[Union[google.cloud.contentwarehouse_v1.types.FetchAclRequest, dict]]):
                 The request object. Request message for
                 DocumentService.FetchAcl
             resource (:class:`str`):
@@ -897,12 +917,12 @@ class DocumentServiceAsyncClient:
 
     async def set_acl(
         self,
-        request: Union[document_service_request.SetAclRequest, dict] = None,
+        request: Optional[Union[document_service_request.SetAclRequest, dict]] = None,
         *,
-        resource: str = None,
-        policy: policy_pb2.Policy = None,
+        resource: Optional[str] = None,
+        policy: Optional[policy_pb2.Policy] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Optional[float] = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> document_service.SetAclResponse:
         r"""Sets the access control policy for a resource.
@@ -935,7 +955,7 @@ class DocumentServiceAsyncClient:
                 print(response)
 
         Args:
-            request (Union[google.cloud.contentwarehouse_v1.types.SetAclRequest, dict]):
+            request (Optional[Union[google.cloud.contentwarehouse_v1.types.SetAclRequest, dict]]):
                 The request object. Request message for
                 DocumentService.SetAcl.
             resource (:class:`str`):
