@@ -16,7 +16,17 @@
 from collections import OrderedDict
 import functools
 import re
-from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
+from typing import (
+    Dict,
+    Mapping,
+    MutableMapping,
+    MutableSequence,
+    Optional,
+    Sequence,
+    Tuple,
+    Type,
+    Union,
+)
 
 from google.api_core import exceptions as core_exceptions
 from google.api_core import gapic_v1
@@ -165,9 +175,9 @@ class RuleSetServiceAsyncClient:
     def __init__(
         self,
         *,
-        credentials: ga_credentials.Credentials = None,
+        credentials: Optional[ga_credentials.Credentials] = None,
         transport: Union[str, RuleSetServiceTransport] = "grpc_asyncio",
-        client_options: ClientOptions = None,
+        client_options: Optional[ClientOptions] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
     ) -> None:
         """Instantiates the rule set service client.
@@ -211,12 +221,14 @@ class RuleSetServiceAsyncClient:
 
     async def create_rule_set(
         self,
-        request: Union[ruleset_service_request.CreateRuleSetRequest, dict] = None,
+        request: Optional[
+            Union[ruleset_service_request.CreateRuleSetRequest, dict]
+        ] = None,
         *,
-        parent: str = None,
-        rule_set: rule_engine.RuleSet = None,
+        parent: Optional[str] = None,
+        rule_set: Optional[rule_engine.RuleSet] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Optional[float] = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> rule_engine.RuleSet:
         r"""Creates a ruleset.
@@ -248,7 +260,7 @@ class RuleSetServiceAsyncClient:
                 print(response)
 
         Args:
-            request (Union[google.cloud.contentwarehouse_v1.types.CreateRuleSetRequest, dict]):
+            request (Optional[Union[google.cloud.contentwarehouse_v1.types.CreateRuleSetRequest, dict]]):
                 The request object. Request message for
                 RuleSetService.CreateRuleSet.
             parent (:class:`str`):
@@ -321,11 +333,13 @@ class RuleSetServiceAsyncClient:
 
     async def get_rule_set(
         self,
-        request: Union[ruleset_service_request.GetRuleSetRequest, dict] = None,
+        request: Optional[
+            Union[ruleset_service_request.GetRuleSetRequest, dict]
+        ] = None,
         *,
-        name: str = None,
+        name: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Optional[float] = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> rule_engine.RuleSet:
         r"""Gets a ruleset. Returns NOT_FOUND if the ruleset does not exist.
@@ -357,7 +371,7 @@ class RuleSetServiceAsyncClient:
                 print(response)
 
         Args:
-            request (Union[google.cloud.contentwarehouse_v1.types.GetRuleSetRequest, dict]):
+            request (Optional[Union[google.cloud.contentwarehouse_v1.types.GetRuleSetRequest, dict]]):
                 The request object. Request message for
                 RuleSetService.GetRuleSet.
             name (:class:`str`):
@@ -432,12 +446,14 @@ class RuleSetServiceAsyncClient:
 
     async def update_rule_set(
         self,
-        request: Union[ruleset_service_request.UpdateRuleSetRequest, dict] = None,
+        request: Optional[
+            Union[ruleset_service_request.UpdateRuleSetRequest, dict]
+        ] = None,
         *,
-        name: str = None,
-        rule_set: rule_engine.RuleSet = None,
+        name: Optional[str] = None,
+        rule_set: Optional[rule_engine.RuleSet] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Optional[float] = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> rule_engine.RuleSet:
         r"""Updates a ruleset. Returns INVALID_ARGUMENT if the name of the
@@ -470,7 +486,7 @@ class RuleSetServiceAsyncClient:
                 print(response)
 
         Args:
-            request (Union[google.cloud.contentwarehouse_v1.types.UpdateRuleSetRequest, dict]):
+            request (Optional[Union[google.cloud.contentwarehouse_v1.types.UpdateRuleSetRequest, dict]]):
                 The request object. Request message for
                 RuleSetService.UpdateRuleSet.
             name (:class:`str`):
@@ -543,11 +559,13 @@ class RuleSetServiceAsyncClient:
 
     async def delete_rule_set(
         self,
-        request: Union[ruleset_service_request.DeleteRuleSetRequest, dict] = None,
+        request: Optional[
+            Union[ruleset_service_request.DeleteRuleSetRequest, dict]
+        ] = None,
         *,
-        name: str = None,
+        name: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Optional[float] = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> None:
         r"""Deletes a ruleset. Returns NOT_FOUND if the document does not
@@ -577,7 +595,7 @@ class RuleSetServiceAsyncClient:
                 await client.delete_rule_set(request=request)
 
         Args:
-            request (Union[google.cloud.contentwarehouse_v1.types.DeleteRuleSetRequest, dict]):
+            request (Optional[Union[google.cloud.contentwarehouse_v1.types.DeleteRuleSetRequest, dict]]):
                 The request object. Request message for
                 RuleSetService.DeleteRuleSet.
             name (:class:`str`):
@@ -634,11 +652,13 @@ class RuleSetServiceAsyncClient:
 
     async def list_rule_sets(
         self,
-        request: Union[ruleset_service_request.ListRuleSetsRequest, dict] = None,
+        request: Optional[
+            Union[ruleset_service_request.ListRuleSetsRequest, dict]
+        ] = None,
         *,
-        parent: str = None,
+        parent: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Optional[float] = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListRuleSetsAsyncPager:
         r"""Lists rulesets.
@@ -671,7 +691,7 @@ class RuleSetServiceAsyncClient:
                     print(response)
 
         Args:
-            request (Union[google.cloud.contentwarehouse_v1.types.ListRuleSetsRequest, dict]):
+            request (Optional[Union[google.cloud.contentwarehouse_v1.types.ListRuleSetsRequest, dict]]):
                 The request object. Request message for
                 RuleSetService.ListRuleSets.
             parent (:class:`str`):
